<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Event extends CI_Controller {

	public function __construct() {
		parent::__construct();
		date_default_timezone_set("Asia/Kolkata");
        $this->load->model('Event_model');
		$this->load->model('Dashboard_model');
		
		if(!$this->session->userdata('logged_in')) {
			redirect(base_url('Login'));
		}
 	}
	
	function listEvents(){
		$template['page'] = 'Event/viewEventList';
        $template['menu'] = 'Event Management';
        $template['smenu'] = 'View Event List';
        $template['pTitle'] = "Event Management";
        $template['pDescription'] = "View Event List";

        $template['event_data'] = $this->Event_model->getEventData();
		$this->load->view('template',$template);
	}

	function addEvent(){
        $this->load->model('Venue_model');

        $template['venue_id'] = '';
        if(isset($_POST['venue_id']) && !empty($_POST['venue_id'])){
            $template['venue_id'] = $_POST['venue_id'];
            $template['venueData'] = $this->Venue_model->getVenueData($template['venue_id']);
        }

        $template['venueList'] = $this->Venue_model->getVenueData();

		$template['page'] = 'Event/eventAddForm';
        $template['menu'] = 'Event Management';
        $template['smenu'] = 'Add Event';
        $template['pTitle'] = "Add Event";
        $template['pDescription'] = "Create New Event";

		$this->load->view('template',$template);
	}

	function createEvent(){
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');

		if(!isset($_POST) || empty($_POST)){
            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/addEvent'));
        }

		$err = 0;
        $errMsg = '';
        if($err == 0 && (!isset($_POST['region_id']) || empty($_POST['region_id']))){
            $err = 1;
            $errMsg = 'Select a region';
        } else if ($err == 0 && (!isset($_POST['event_name']) || $_POST['event_name'] == '' )){
            $err = 1;
            $errMsg = 'Provide a Event Name';
        } else if ($err == 0 && (!isset($_POST['location']) || $_POST['location'] == '' )){
            $err = 1;
            $errMsg = 'Provide a Location';
        } else if ($err == 0 && (!isset($_POST['host_cat_id']) || $_POST['host_cat_id'] == '' )){
            $err = 1;
            $errMsg = 'Select a Host';
        } else if ($err == 0 && (!isset($_POST['event_details']) || $_POST['event_details'] == '' )){
            $err = 1;
            $errMsg = 'Provide Proper Event Details';
        } else if ($err == 0 && isset($_POST['has_layout']) && $_POST['has_layout'] == 1 && 
          (!isset($_POST['seat_color']) || empty($_POST['seat_color']) || !isset($_FILES) || 
           !isset($_POST['seat_price']) || empty($_POST['seat_price']) || empty($_FILES) || 
           count($_POST['seat_price']) != count($_POST['seat_color'])) || !isset($_FILES['layout_image'])||
           empty($_FILES['layout_image'])){
            $err = 1;
            $errMsg = 'Provide Proper Layout details';
        }

        if(isset($_POST['has_layout']) && $_POST['has_layout'] == 1){
            $config = set_upload_service("assets/uploads/services");
            $this->load->library('upload');
            $config['file_name'] = time()."_".$_FILES['layout_image']['name'];
            $this->upload->initialize($config);
            if(!$this->upload->do_upload('layout_image')){
                $err = 1;
                $errMsg = $this->upload->display_errors();
            }else{
                $upload_data = $this->upload->data();
                $_POST['layout'] = $config['upload_path']."/".$upload_data['file_name'];
            }

            $seatLayoutDetails = array();
            foreach($_POST['seat_color'] AS $index => $value){
                $seatLayoutDetails[] = array('color'=>$value,'price'=>$_POST['seat_price'][$index]);
            }
            $_POST['layout_details'] = json_encode($seatLayoutDetails);
        } else {
            $_POST['layout'] = $_POST['layout_details'] = '';
        }

        $locData = getLocationLatLng($_POST['location']);
        if(empty($locData)){
            $err = 1;
            $errMsg = 'Provide a valid Location';
        }

        if($err == 1){
            $flashMsg['message'] = $errMsg;
            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/addEvent'));
        }

        $_POST['location_lat'] = $locData['lat'];
        $_POST['location_lng'] = $locData['lng'];

        unset($_POST['has_layout'],$_POST['seat_color'],$_POST['seat_price']);

        $status = $this->Event_model->createEvent($_POST);
        if($status == 1){
            $flashMsg['class'] = 'success';
            $flashMsg['message'] = 'Event Created';

            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/listEvent'));
        }
        $this->session->set_flashdata('message',$flashMsg);
        redirect(base_url('Event/addEvent'));
	}

	function editEvent($event_id=''){
        $flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
		if(empty($event_id) || empty(decode_param($event_id))){
			$this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/listEvent'));
		}
		$template['page'] = 'Event/eventAddForm';
        $template['menu'] = 'Event Management';
        $template['smenu'] = 'Edit Event';
        $template['pTitle'] = "Edit Event";
        $template['pDescription'] = "Update Event Data";

        $template['event_id'] = $event_id;
        $template['event_data'] = $this->Event_model->getEventData(decode_param($event_id));

        $this->load->model('Host_model');
        $this->load->model('Region_model');
        $template['host_data'] = $this->Host_model->getHostCategories();
        $template['regionData'] = $this->Region_model->getRegionData();

		$this->load->view('template',$template);
	}

	function updateEvent($event_id=''){
		$flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');

		if(!isset($_POST) || empty($_POST) || empty($event_id)){
            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/listEvent'));
        }

        $err = 0;
        $errMsg = '';
        if($err == 0 && (!isset($_POST['region_id']) || empty($_POST['region_id']))){
            $err = 1;
            $errMsg = 'Select a region';
        } else if ($err == 0 && (!isset($_POST['event_name']) || $_POST['event_name'] == '' )){
            $err = 1;
            $errMsg = 'Provide a Event Name';
        } else if ($err == 0 && (!isset($_POST['location']) || $_POST['location'] == '' )){
            $err = 1;
            $errMsg = 'Provide a Location';
        } else if ($err == 0 && (!isset($_POST['host_cat_id']) || $_POST['host_cat_id'] == '' )){
            $err = 1;
            $errMsg = 'Select a Host';
        } else if ($err == 0 && (!isset($_POST['event_details']) || $_POST['event_details'] == '' )){
            $err = 1;
            $errMsg = 'Provide Proper Event Details';
        } else if ($err == 0 && isset($_POST['has_layout']) && $_POST['has_layout'] == 1 && 
          (!isset($_FILES,$_POST['seat_price'],$_POST['seat_color'],$_FILES['layout_image']) || 
           empty($_POST['seat_color']) || empty($_POST['seat_price']) || empty($_FILES) || 
           count($_POST['seat_price']) != count($_POST['seat_color']) || empty($_FILES['layout_image']))){
            $err = 1;
            $errMsg = 'Provide Proper Layout details';
        }

        if(isset($_POST['has_layout']) && $_POST['has_layout'] == 1){
            $config = set_upload_service("assets/uploads/services");
            $this->load->library('upload');
            $config['file_name'] = time()."_".$_FILES['layout_image']['name'];
            $this->upload->initialize($config);
            if($this->upload->do_upload('layout_image')){
                $upload_data = $this->upload->data();
                $_POST['layout'] = $config['upload_path']."/".$upload_data['file_name'];
            }

            $seatLayoutDetails = array();
            foreach($_POST['seat_color'] AS $index => $value){
                $seatLayoutDetails[] = array('color'=>$value,'price'=>$_POST['seat_price'][$index]);
            }
            $_POST['layout_details'] = json_encode($seatLayoutDetails);
        } else {
            $_POST['layout'] = $_POST['layout_details'] = '';
        }

        $locData = getLocationLatLng($_POST['location']);
        if(empty($locData)){
            $err = 1;
            $errMsg = 'Provide a valid Location';
        }

        if($err == 1){
            $flashMsg['message'] = $errMsg;
            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/addEvent'));
        }

        $_POST['location_lat'] = $locData['lat'];
        $_POST['location_lng'] = $locData['lng'];

        unset($_POST['has_layout'],$_POST['seat_color'],$_POST['seat_price']);

        $status = $this->Event_model->updateEvent(decode_param($event_id),$_POST);
        if($status == 1){
            $flashMsg['class'] = 'success';
            $flashMsg['message'] = 'Event Created';

            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/listEvent'));
        }
        $this->session->set_flashdata('message',$flashMsg);
        redirect(base_url('Event/editEvent/'.$event_id));
	}

    function changeStatus($event_id = '',$status = '1'){
        $flashMsg = array('message'=>'Something went wrong, please try again..!','class'=>'error');
        if(empty($event_id)){
            $this->session->set_flashdata('message',$flashMsg);
            redirect(base_url('Event/listEvent'));
        }
        $event_id = decode_param($event_id);
        $status = $this->Event_model->changeStatus($event_id,$status);
        if(!$status){
            $this->session->set_flashdata('message',$flashMsg);
        }
        redirect(base_url('Event/listEvent'));
    }

    function getEventData(){
        $resArr = array('status'=>0);
        if(!isset($_POST) || empty($_POST) || !isset($_POST['event_id']) || empty($_POST['event_id']) || 
           empty($event_id = decode_param($_POST['event_id']))){
            echo json_encode($resArr);exit;
        }
        $eventData = $this->Event_model->getEventData($event_id);
        if(!empty($eventData)){
            $resArr['status'] = 1;
            $resArr['data'] = $eventData;
        }
        echo json_encode($resArr);exit;
    }
}
?>